---
title: <span class="badge object-type-scalar"></span> Fahrenheit
---
# <span class="badge object-type-scalar"></span> Fahrenheit

Temperature: Fahrenheit (°F)

## Definition

```python
# Temperature: Fahrenheit (°F)
Fahrenheit: typing.Literal["fahrenheit"] = "fahrenheit"
```
